install using `pip install gauss-linear` (requires Python 3.8+)
then just do
`gauss` and then paste in the matrix
### some options: 
`n` - computes the null space
`r` - computes a row echelon form
`rr` - computes the rref
`inv` - computes the inverse
`orthoproject` - orthogonal projections
`q` - ends the program

there's a lot more commands, you can figure those out yourself lol
